@@ -13,7 +13,7 @@ import (
 func loadConfig(path string) (config.Project, error) {
 	p, path, err := loadConfigCheck(path)
 	if err == nil {
-		log.WithField("path", path).Info("loading")
+		log.WithField("path", path).Debug("using configuration")
 	}
 	return p, err
 }
