@@ -5,6 +5,7 @@ import (
 	"go/ast"
 	"go/parser"
 	"go/token"
+	"maps"
 	"os"
 	"os/exec"
 	"path/filepath"
@@ -15,6 +16,7 @@ import (
 	"github.com/caarlos0/log"
 	"github.com/goreleaser/goreleaser/v2/internal/artifact"
 	"github.com/goreleaser/goreleaser/v2/internal/builders/buildtarget"
+	"github.com/goreleaser/goreleaser/v2/internal/experimental"
 	"github.com/goreleaser/goreleaser/v2/internal/gio"
 	"github.com/goreleaser/goreleaser/v2/internal/logext"
 	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
@@ -62,15 +64,28 @@ func (*Builder) WithDefaults(build config.Build) (config.Build, error) {
 		if len(build.Goarch) == 0 {
 			build.Goarch = []string{"amd64", "arm64", "386"}
 		}
+		if len(build.Goamd64) == 0 {
+			build.Goamd64 = []string{"v1"}
+		}
+		if len(build.Go386) == 0 {
+			build.Go386 = []string{"sse2"}
+		}
 		if len(build.Goarm) == 0 {
-			build.Goarm = []string{"6"}
+			build.Goarm = []string{experimental.DefaultGOARM()}
+		}
+		if len(build.Goarm64) == 0 {
+			build.Goarm64 = []string{"v8.0"}
 		}
 		if len(build.Gomips) == 0 {
 			build.Gomips = []string{"hardfloat"}
 		}
-		if len(build.Goamd64) == 0 {
-			build.Goamd64 = []string{"v1"}
+		if len(build.Goppc64) == 0 {
+			build.Goppc64 = []string{"power8"}
 		}
+		if len(build.Goriscv64) == 0 {
+			build.Goriscv64 = []string{"rva20u64"}
+		}
+
 		targets, err := buildtarget.List(build)
 		if err != nil {
 			return build, err
@@ -82,32 +97,46 @@ func (*Builder) WithDefaults(build config.Build) (config.Build, error) {
 			if target == go118FirstClassTargetsName ||
 				target == goStableFirstClassTargetsName {
 				for _, t := range go118FirstClassTargets {
-					targets[t] = true
+					targets[fixTarget(t)] = true
 				}
 				continue
 			}
-			if strings.HasSuffix(target, "_amd64") {
-				targets[target+"_v1"] = true
-				continue
-			}
-			if strings.HasSuffix(target, "_arm") {
-				targets[target+"_6"] = true
-				continue
-			}
-			if strings.HasSuffix(target, "_mips") ||
-				strings.HasSuffix(target, "_mips64") ||
-				strings.HasSuffix(target, "_mipsle") ||
-				strings.HasSuffix(target, "_mips64le") {
-				targets[target+"_hardfloat"] = true
-				continue
-			}
-			targets[target] = true
+			targets[fixTarget(target)] = true
 		}
-		build.Targets = keys(targets)
+		build.Targets = slices.Collect(maps.Keys(targets))
 	}
 	return build, nil
 }
 
+func fixTarget(target string) string {
+	if strings.HasSuffix(target, "_amd64") {
+		return target + "_v1"
+	}
+	if strings.HasSuffix(target, "_386") {
+		return target + "_sse2"
+	}
+	if strings.HasSuffix(target, "_arm") {
+		return target + "_" + experimental.DefaultGOARM()
+	}
+	if strings.HasSuffix(target, "_arm64") {
+		return target + "_v8.0"
+	}
+	if strings.HasSuffix(target, "_mips") ||
+		strings.HasSuffix(target, "_mips64") ||
+		strings.HasSuffix(target, "_mipsle") ||
+		strings.HasSuffix(target, "_mips64le") {
+		return target + "_hardfloat"
+	}
+	if strings.HasSuffix(target, "_ppc64") ||
+		strings.HasSuffix(target, "_ppc64le") {
+		return target + "_power8"
+	}
+	if strings.HasSuffix(target, "_riscv64") {
+		return target + "_rva20u64"
+	}
+	return target
+}
+
 func warnIfTargetsAndOtherOptionTogether(build config.Build) bool {
 	if len(build.Targets) == 0 {
 		return false
@@ -115,12 +144,16 @@ func warnIfTargetsAndOtherOptionTogether(build config.Build) bool {
 
 	res := false
 	for k, v := range map[string]int{
-		"goos":    len(build.Goos),
-		"goarch":  len(build.Goarch),
-		"goarm":   len(build.Goarm),
-		"gomips":  len(build.Gomips),
-		"goamd64": len(build.Goamd64),
-		"ignore":  len(build.Ignore),
+		"goos":      len(build.Goos),
+		"goarch":    len(build.Goarch),
+		"go386":     len(build.Go386),
+		"goamd64":   len(build.Goamd64),
+		"goarm":     len(build.Goarm),
+		"goarm64":   len(build.Goarm64),
+		"gomips":    len(build.Gomips),
+		"goppc64":   len(build.Goppc64),
+		"goriscv64": len(build.Goriscv64),
+		"ignore":    len(build.Ignore),
 	} {
 		if v == 0 {
 			continue
@@ -131,14 +164,6 @@ func warnIfTargetsAndOtherOptionTogether(build config.Build) bool {
 	return res
 }
 
-func keys(m map[string]bool) []string {
-	result := make([]string, 0, len(m))
-	for k := range m {
-		result = append(result, k)
-	}
-	return result
-}
-
 const (
 	go118FirstClassTargetsName    = "go_118_first_class"
 	goStableFirstClassTargetsName = "go_first_class"
@@ -146,14 +171,14 @@ const (
 
 // go tool dist list -json | jq -r '.[] | select(.FirstClass) | [.GOOS, .GOARCH] | @tsv'
 var go118FirstClassTargets = []string{
-	"darwin_amd64_v1",
+	"darwin_amd64",
 	"darwin_arm64",
 	"linux_386",
-	"linux_amd64_v1",
-	"linux_arm_6",
+	"linux_amd64",
+	"linux_arm",
 	"linux_arm64",
 	"windows_386",
-	"windows_amd64_v1",
+	"windows_amd64",
 }
 
 // Build builds a golang build.
@@ -163,14 +188,18 @@ func (*Builder) Build(ctx *context.Context, build config.Build, options api.Opti
 	}
 
 	a := &artifact.Artifact{
-		Type:    artifact.Binary,
-		Path:    options.Path,
-		Name:    options.Name,
-		Goos:    options.Goos,
-		Goarch:  options.Goarch,
-		Goamd64: options.Goamd64,
-		Goarm:   options.Goarm,
-		Gomips:  options.Gomips,
+		Type:      artifact.Binary,
+		Path:      options.Path,
+		Name:      options.Name,
+		Goos:      options.Goos,
+		Goarch:    options.Goarch,
+		Goamd64:   options.Goamd64,
+		Go386:     options.Go386,
+		Goarm:     options.Goarm,
+		Goarm64:   options.Goarm64,
+		Gomips:    options.Gomips,
+		Goppc64:   options.Goppc64,
+		Goriscv64: options.Goriscv64,
 		Extra: map[string]interface{}{
 			artifact.ExtraBinary: strings.TrimSuffix(filepath.Base(options.Path), options.Ext),
 			artifact.ExtraExt:    options.Ext,
@@ -213,10 +242,14 @@ func (*Builder) Build(ctx *context.Context, build config.Build, options api.Opti
 		env,
 		"GOOS="+options.Goos,
 		"GOARCH="+options.Goarch,
+		"GOAMD64="+options.Goamd64,
+		"GO386="+options.Go386,
 		"GOARM="+options.Goarm,
+		"GOARM64="+options.Goarm64,
 		"GOMIPS="+options.Gomips,
 		"GOMIPS64="+options.Gomips,
-		"GOAMD64="+options.Goamd64,
+		"GOPPC64="+options.Goppc64,
+		"GORISCV64"+options.Goriscv64,
 	)
 
 	if v := os.Getenv("GOCACHEPROG"); v != "" {
@@ -249,9 +282,9 @@ func (*Builder) Build(ctx *context.Context, build config.Build, options api.Opti
 }
 
 func withOverrides(ctx *context.Context, build config.Build, options api.Options) (config.BuildDetails, error) {
-	optsTarget := options.Goos + options.Goarch + options.Goarm + options.Gomips + options.Goamd64
+	optsTarget := options.Goos + options.Goarch + options.Goamd64 + options.Go386 + options.Goarm + options.Goarm64 + options.Gomips + options.Goppc64 + options.Goriscv64
 	for _, o := range build.BuildDetailsOverrides {
-		overrideTarget, err := tmpl.New(ctx).Apply(o.Goos + o.Goarch + o.Gomips + o.Goarm + o.Goamd64)
+		overrideTarget, err := tmpl.New(ctx).Apply(o.Goos + o.Goarch + o.Goamd64 + o.Go386 + o.Goarm + o.Goarm64 + o.Gomips + o.Goppc64 + o.Goriscv64)
 		if err != nil {
 			return build.BuildDetails, err
 		}
@@ -481,14 +514,18 @@ func getHeaderArtifactForLibrary(build config.Build, options api.Options) *artif
 	headerName := basePath + ".h"
 
 	return &artifact.Artifact{
-		Type:    artifact.Header,
-		Path:    fullPath,
-		Name:    headerName,
-		Goos:    options.Goos,
-		Goarch:  options.Goarch,
-		Goamd64: options.Goamd64,
-		Goarm:   options.Goarm,
-		Gomips:  options.Gomips,
+		Type:      artifact.Header,
+		Path:      fullPath,
+		Name:      headerName,
+		Goos:      options.Goos,
+		Goarch:    options.Goarch,
+		Goamd64:   options.Goamd64,
+		Go386:     options.Go386,
+		Goarm:     options.Goarm,
+		Goarm64:   options.Goarm64,
+		Gomips:    options.Gomips,
+		Goppc64:   options.Goppc64,
+		Goriscv64: options.Goriscv64,
 		Extra: map[string]interface{}{
 			artifact.ExtraBinary: headerName,
 			artifact.ExtraExt:    ".h",
