@@ -22,6 +22,17 @@ import (
 
 var runtimeTarget = runtime.GOOS + "_" + runtime.GOARCH
 
+var go118FirstClassAdjustedTargets = []string{
+	"darwin_amd64_v1",
+	"darwin_arm64_v8.0",
+	"linux_386_sse2",
+	"linux_amd64_v1",
+	"linux_arm_6",
+	"linux_arm64_v8.0",
+	"windows_386_sse2",
+	"windows_amd64_v1",
+}
+
 func TestWithDefaults(t *testing.T) {
 	for name, testcase := range map[string]struct {
 		build    config.Build
@@ -74,13 +85,13 @@ func TestWithDefaults(t *testing.T) {
 			},
 			targets: []string{
 				"linux_amd64_v1",
-				"linux_386",
-				"linux_arm64",
+				"linux_386_sse2",
+				"linux_arm64_v8.0",
 				"darwin_amd64_v1",
-				"darwin_arm64",
+				"darwin_arm64_v8.0",
 				"windows_amd64_v1",
-				"windows_arm64",
-				"windows_386",
+				"windows_arm64_v8.0",
+				"windows_386_sse2",
 			},
 			goBinary: "go",
 		},
@@ -89,12 +100,12 @@ func TestWithDefaults(t *testing.T) {
 				ID:     "foo3",
 				Binary: "foo",
 				Targets: []string{
-					"linux_386",
+					"linux_386_sse2",
 					"darwin_amd64_v2",
 				},
 			},
 			targets: []string{
-				"linux_386",
+				"linux_386_sse2",
 				"darwin_amd64_v2",
 			},
 			goBinary: "go",
@@ -104,12 +115,12 @@ func TestWithDefaults(t *testing.T) {
 				ID:     "foo3",
 				Binary: "foo",
 				Targets: []string{
-					"linux_386",
+					"linux_386_sse2",
 					"darwin_amd64",
 				},
 			},
 			targets: []string{
-				"linux_386",
+				"linux_386_sse2",
 				"darwin_amd64_v1",
 			},
 			goBinary: "go",
@@ -123,6 +134,33 @@ func TestWithDefaults(t *testing.T) {
 			targets:  []string{"linux_arm_6"},
 			goBinary: "go",
 		},
+		"custom targets no arm64": {
+			build: config.Build{
+				ID:      "foo3",
+				Binary:  "foo",
+				Targets: []string{"linux_arm64"},
+			},
+			targets:  []string{"linux_arm64_v8.0"},
+			goBinary: "go",
+		},
+		"custom targets no ppc64": {
+			build: config.Build{
+				ID:      "foo3",
+				Binary:  "foo",
+				Targets: []string{"linux_ppc64le", "linux_ppc64"},
+			},
+			targets:  []string{"linux_ppc64le_power8", "linux_ppc64_power8"},
+			goBinary: "go",
+		},
+		"custom targets no riscv64": {
+			build: config.Build{
+				ID:      "foo3",
+				Binary:  "foo",
+				Targets: []string{"linux_riscv64"},
+			},
+			targets:  []string{"linux_riscv64_rva20u64"},
+			goBinary: "go",
+		},
 		"custom targets no mips": {
 			build: config.Build{
 				ID:      "foo3",
@@ -167,13 +205,13 @@ func TestWithDefaults(t *testing.T) {
 			},
 			targets: []string{
 				"linux_amd64_v1",
-				"linux_386",
-				"linux_arm64",
+				"linux_386_sse2",
+				"linux_arm64_v8.0",
 				"darwin_amd64_v1",
-				"darwin_arm64",
+				"darwin_arm64_v8.0",
 				"windows_amd64_v1",
-				"windows_arm64",
-				"windows_386",
+				"windows_arm64_v8.0",
+				"windows_386_sse2",
 			},
 			goBinary: "go",
 		},
@@ -185,13 +223,13 @@ func TestWithDefaults(t *testing.T) {
 			},
 			targets: []string{
 				"linux_amd64_v1",
-				"linux_386",
-				"linux_arm64",
+				"linux_386_sse2",
+				"linux_arm64_v8.0",
 				"darwin_amd64_v1",
-				"darwin_arm64",
+				"darwin_arm64_v8.0",
 				"windows_amd64_v1",
-				"windows_arm64",
-				"windows_386",
+				"windows_arm64_v8.0",
+				"windows_386_sse2",
 			},
 			goBinary: "go",
 		},
@@ -201,7 +239,7 @@ func TestWithDefaults(t *testing.T) {
 				Binary:  "foo",
 				Targets: []string{goStableFirstClassTargetsName},
 			},
-			targets:  go118FirstClassTargets,
+			targets:  go118FirstClassAdjustedTargets,
 			goBinary: "go",
 		},
 		"go 1.18 first class targets": {
@@ -210,7 +248,7 @@ func TestWithDefaults(t *testing.T) {
 				Binary:  "foo",
 				Targets: []string{go118FirstClassTargetsName},
 			},
-			targets:  go118FirstClassTargets,
+			targets:  go118FirstClassAdjustedTargets,
 			goBinary: "go",
 		},
 		"go 1.18 first class targets plus custom": {
@@ -219,7 +257,7 @@ func TestWithDefaults(t *testing.T) {
 				Binary:  "foo",
 				Targets: []string{"linux_amd64_v1", go118FirstClassTargetsName, "darwin_amd64_v2"},
 			},
-			targets:  append(go118FirstClassTargets, "darwin_amd64_v2"),
+			targets:  append(go118FirstClassAdjustedTargets, "darwin_amd64_v2"),
 			goBinary: "go",
 		},
 		"repeatin targets": {
@@ -228,7 +266,7 @@ func TestWithDefaults(t *testing.T) {
 				Binary:  "foo",
 				Targets: []string{go118FirstClassTargetsName, go118FirstClassTargetsName, goStableFirstClassTargetsName},
 			},
-			targets:  go118FirstClassTargets,
+			targets:  go118FirstClassAdjustedTargets,
 			goBinary: "go",
 		},
 	} {
@@ -416,7 +454,15 @@ func TestBuild(t *testing.T) {
 		})
 		require.NoError(t, err)
 	}
-	require.ElementsMatch(t, ctx.Artifacts.List(), []*artifact.Artifact{
+	list := ctx.Artifacts
+	require.NoError(t, list.Visit(func(a *artifact.Artifact) error {
+		s, err := filepath.Rel(folder, a.Path)
+		if err == nil {
+			a.Path = s
+		}
+		return nil
+	}))
+	require.ElementsMatch(t, list.List(), []*artifact.Artifact{
 		{
 			Name:   "bin/foo-v5.6.7",
 			Path:   filepath.Join("dist", "linux_amd64", "bin", "foo-v5.6.7"),
@@ -1225,33 +1271,43 @@ func TestBuildGoBuildLine(t *testing.T) {
 }
 
 func TestOverrides(t *testing.T) {
-	t.Run("linux amd64", func(t *testing.T) {
-		dets, err := withOverrides(
-			testctx.New(),
-			config.Build{
-				BuildDetails: config.BuildDetails{
-					Ldflags: []string{"original"},
-					Env:     []string{"BAR=foo", "FOO=bar"},
-				},
-				BuildDetailsOverrides: []config.BuildDetailsOverride{
-					{
-						Goos:   "linux",
-						Goarch: "amd64",
-						BuildDetails: config.BuildDetails{
-							Ldflags: []string{"overridden"},
-							Env:     []string{"FOO=overridden"},
+	for _, arch := range []string{
+		"amd64",
+		"arm64",
+		"ppc64",
+		"ppc64le",
+		"riscv64",
+		"386",
+		"mips",
+	} {
+		t.Run("linux "+arch, func(t *testing.T) {
+			dets, err := withOverrides(
+				testctx.New(),
+				config.Build{
+					BuildDetails: config.BuildDetails{
+						Ldflags: []string{"original"},
+						Env:     []string{"BAR=foo", "FOO=bar"},
+					},
+					BuildDetailsOverrides: []config.BuildDetailsOverride{
+						{
+							Goos:   "linux",
+							Goarch: arch,
+							BuildDetails: config.BuildDetails{
+								Ldflags: []string{"overridden"},
+								Env:     []string{"FOO=overridden"},
+							},
 						},
 					},
+				}, api.Options{
+					Goos:   "linux",
+					Goarch: arch,
 				},
-			}, api.Options{
-				Goos:   "linux",
-				Goarch: "amd64",
-			},
-		)
-		require.NoError(t, err)
-		require.ElementsMatch(t, dets.Ldflags, []string{"overridden"})
-		require.ElementsMatch(t, dets.Env, []string{"BAR=foo", "FOO=overridden"})
-	})
+			)
+			require.NoError(t, err)
+			require.ElementsMatch(t, dets.Ldflags, []string{"overridden"})
+			require.ElementsMatch(t, dets.Env, []string{"BAR=foo", "FOO=overridden"})
+		})
+	}
 
 	t.Run("single sided", func(t *testing.T) {
 		dets, err := withOverrides(
@@ -1332,6 +1388,36 @@ func TestOverrides(t *testing.T) {
 		testlib.RequireTemplateError(t, err)
 	})
 
+	t.Run("with goarm64", func(t *testing.T) {
+		dets, err := withOverrides(
+			testctx.New(),
+			config.Build{
+				BuildDetails: config.BuildDetails{
+					Ldflags: []string{"original"},
+				},
+				BuildDetailsOverrides: []config.BuildDetailsOverride{
+					{
+						Goos:    "linux",
+						Goarch:  "arm64",
+						Goarm64: "v8.0",
+						BuildDetails: config.BuildDetails{
+							Ldflags: []string{"overridden"},
+						},
+					},
+				},
+			}, api.Options{
+				Goos:    "linux",
+				Goarch:  "arm64",
+				Goarm64: "v8.0",
+			},
+		)
+		require.NoError(t, err)
+		require.Equal(t, config.BuildDetails{
+			Ldflags: []string{"overridden"},
+			Env:     []string{},
+		}, dets)
+	})
+
 	t.Run("with goarm", func(t *testing.T) {
 		dets, err := withOverrides(
 			testctx.New(),
@@ -1391,23 +1477,87 @@ func TestOverrides(t *testing.T) {
 			Env:     []string{},
 		}, dets)
 	})
+
+	t.Run("with goriscv64", func(t *testing.T) {
+		dets, err := withOverrides(
+			testctx.New(),
+			config.Build{
+				BuildDetails: config.BuildDetails{
+					Ldflags: []string{"original"},
+				},
+				BuildDetailsOverrides: []config.BuildDetailsOverride{
+					{
+						Goos:      "linux",
+						Goarch:    "riscv64",
+						Goriscv64: "rva22u64",
+						BuildDetails: config.BuildDetails{
+							Ldflags: []string{"overridden"},
+						},
+					},
+				},
+			}, api.Options{
+				Goos:      "linux",
+				Goarch:    "riscv64",
+				Goriscv64: "rva22u64",
+			},
+		)
+		require.NoError(t, err)
+		require.Equal(t, config.BuildDetails{
+			Ldflags: []string{"overridden"},
+			Env:     []string{},
+		}, dets)
+	})
+
+	t.Run("with go386", func(t *testing.T) {
+		dets, err := withOverrides(
+			testctx.New(),
+			config.Build{
+				BuildDetails: config.BuildDetails{
+					Ldflags: []string{"original"},
+				},
+				BuildDetailsOverrides: []config.BuildDetailsOverride{
+					{
+						Goos:   "linux",
+						Goarch: "386",
+						Go386:  "sse2",
+						BuildDetails: config.BuildDetails{
+							Ldflags: []string{"overridden"},
+						},
+					},
+				},
+			}, api.Options{
+				Goos:   "linux",
+				Goarch: "386",
+				Go386:  "sse2",
+			},
+		)
+		require.NoError(t, err)
+		require.Equal(t, config.BuildDetails{
+			Ldflags: []string{"overridden"},
+			Env:     []string{},
+		}, dets)
+	})
 }
 
 func TestWarnIfTargetsAndOtherOptionsTogether(t *testing.T) {
 	nonEmpty := []string{"foo", "bar"}
 	for name, fn := range map[string]func(*config.Build){
 		"goos":    func(b *config.Build) { b.Goos = nonEmpty },
+		"goamd64": func(b *config.Build) { b.Goamd64 = nonEmpty },
 		"goarch":  func(b *config.Build) { b.Goarch = nonEmpty },
 		"goarm":   func(b *config.Build) { b.Goarm = nonEmpty },
 		"gomips":  func(b *config.Build) { b.Gomips = nonEmpty },
-		"goamd64": func(b *config.Build) { b.Goamd64 = nonEmpty },
 		"ignores": func(b *config.Build) { b.Ignore = []config.IgnoredBuild{{Goos: "linux"}} },
 		"multiple": func(b *config.Build) {
 			b.Goos = nonEmpty
 			b.Goarch = nonEmpty
-			b.Goarm = nonEmpty
-			b.Gomips = nonEmpty
 			b.Goamd64 = nonEmpty
+			b.Go386 = nonEmpty
+			b.Goarm = nonEmpty
+			b.Goarm64 = nonEmpty
+			b.Gomips = nonEmpty
+			b.Goppc64 = nonEmpty
+			b.Goriscv64 = nonEmpty
 			b.Ignore = []config.IgnoredBuild{{Goos: "linux"}}
 		},
 	} {
