@@ -9,14 +9,14 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/goreleaser/goreleaser/internal/artifact"
-	"github.com/goreleaser/goreleaser/internal/client"
-	"github.com/goreleaser/goreleaser/internal/golden"
-	"github.com/goreleaser/goreleaser/internal/testctx"
-	"github.com/goreleaser/goreleaser/internal/testlib"
-	"github.com/goreleaser/goreleaser/internal/tmpl"
-	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/client"
+	"github.com/goreleaser/goreleaser/v2/internal/golden"
+	"github.com/goreleaser/goreleaser/v2/internal/testctx"
+	"github.com/goreleaser/goreleaser/v2/internal/testlib"
+	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 	"github.com/stretchr/testify/require"
 )
 
@@ -368,6 +368,10 @@ func TestRunPipePullRequest(t *testing.T) {
 						Branch: "update-{{.Version}}",
 						PullRequest: config.PullRequest{
 							Enabled: true,
+							Base: config.PullRequestBase{
+								Owner: "og",
+								Name:  "bar",
+							},
 						},
 					},
 				},
@@ -400,6 +404,7 @@ func TestRunPipePullRequest(t *testing.T) {
 	require.NoError(t, publishAll(ctx, client))
 	require.True(t, client.CreatedFile)
 	require.True(t, client.OpenedPullRequest)
+	require.True(t, client.SyncedFork)
 	golden.RequireEqualYaml(t, []byte(client.Content))
 }
 
@@ -962,7 +967,7 @@ func TestDefault(t *testing.T) {
 		ProjectName: "myproject",
 		Krews: []config.Krew{
 			{
-				Index: config.RepoRef{
+				Repository: config.RepoRef{
 					Git: config.GitRepoRef{
 						URL: "foo/bar",
 					},
@@ -976,7 +981,6 @@ func TestDefault(t *testing.T) {
 	require.NotEmpty(t, ctx.Config.Krews[0].CommitAuthor.Email)
 	require.NotEmpty(t, ctx.Config.Krews[0].CommitMessageTemplate)
 	require.Equal(t, "foo/bar", ctx.Config.Krews[0].Repository.Git.URL)
-	require.True(t, ctx.Deprecated)
 }
 
 func TestGHFolder(t *testing.T) {
