@@ -105,7 +105,6 @@ func TestRunPipe(t *testing.T) {
 		f, err := os.Create(name)
 		require.NoError(t, err)
 		require.NoError(t, f.Close())
-
 	}
 	libPrefix := `/usr/lib
       {{- if eq .Arch "amd64" }}{{if eq .Format "rpm"}}_rpm{{end}}64{{- end -}}
@@ -397,7 +396,7 @@ func TestRunPipe(t *testing.T) {
 	for _, pkg := range packages {
 		format := pkg.Format()
 		require.NotEmpty(t, format)
-		require.Equal(t, pkg.Format(), artifact.ExtraOr(*pkg, artifact.ExtraExt, ""))
+		require.Equal(t, "."+pkg.Format(), artifact.ExtraOr(*pkg, artifact.ExtraExt, ""))
 		arch := pkg.Goarch
 		if pkg.Goarm != "" {
 			arch += "v" + pkg.Goarm
@@ -533,12 +532,24 @@ func doTestRunPipeConventionalNameTemplate(t *testing.T, snapshot bool) {
 		ctx.Snapshot = true
 	}
 	for _, goos := range []string{"linux", "darwin", "aix"} {
-		for _, goarch := range []string{"amd64", "386", "arm64", "arm", "mips", "ppc64"} {
+		for _, goarch := range []string{"amd64", "386", "arm64", "arm", "mips", "ppc64", "riscv64"} {
 			if goarch == "ppc64" && goos != "aix" {
 				continue
 			}
 
 			switch goarch {
+			case "arm64":
+				ctx.Artifacts.Add(&artifact.Artifact{
+					Name:    "subdir/mybin",
+					Path:    binPath,
+					Goarch:  goarch,
+					Goos:    goos,
+					Goarm64: "v8.0",
+					Type:    artifact.Binary,
+					Extra: map[string]interface{}{
+						artifact.ExtraID: "default",
+					},
+				})
 			case "arm":
 				for _, goarm := range []string{"6", "7"} {
 					ctx.Artifacts.Add(&artifact.Artifact{
@@ -581,6 +592,42 @@ func doTestRunPipeConventionalNameTemplate(t *testing.T, snapshot bool) {
 						},
 					})
 				}
+			case "386":
+				ctx.Artifacts.Add(&artifact.Artifact{
+					Name:   "subdir/mybin",
+					Path:   binPath,
+					Goarch: goarch,
+					Goos:   goos,
+					Go386:  "sse2",
+					Type:   artifact.Binary,
+					Extra: map[string]interface{}{
+						artifact.ExtraID: "default",
+					},
+				})
+			case "riscv64":
+				ctx.Artifacts.Add(&artifact.Artifact{
+					Name:      "subdir/mybin",
+					Path:      binPath,
+					Goarch:    goarch,
+					Goos:      goos,
+					Goriscv64: "rva22u64",
+					Type:      artifact.Binary,
+					Extra: map[string]interface{}{
+						artifact.ExtraID: "default",
+					},
+				})
+			case "ppc64":
+				ctx.Artifacts.Add(&artifact.Artifact{
+					Name:    "subdir/mybin",
+					Path:    binPath,
+					Goarch:  goarch,
+					Goos:    goos,
+					Goppc64: "power9",
+					Type:    artifact.Binary,
+					Extra: map[string]interface{}{
+						artifact.ExtraID: "default",
+					},
+				})
 			default:
 				ctx.Artifacts.Add(&artifact.Artifact{
 					Name:   "subdir/mybin",
@@ -597,7 +644,7 @@ func doTestRunPipeConventionalNameTemplate(t *testing.T, snapshot bool) {
 	}
 	require.NoError(t, Pipe{}.Run(ctx))
 	packages := ctx.Artifacts.Filter(artifact.ByType(artifact.LinuxPackage)).List()
-	require.Len(t, packages, 48)
+	require.Len(t, packages, 52)
 	prefix := "foo"
 	if snapshot {
 		prefix += "-snapshot"
@@ -662,6 +709,11 @@ func doTestRunPipeConventionalNameTemplate(t *testing.T, snapshot bool) {
 			prefix + "-1.0.0-1-x86_64v4.pkg.tar.zst",
 			prefix + "-1.0.0-1-mips.pkg.tar.zst",
 			prefix + "-1.0.0-1-mips.pkg.tar.zst",
+			prefix + "-1.0.0-1-riscv64.pkg.tar.zst",
+			prefix + "_1.0.0_riscv64.apk",
+			prefix + "-1.0.0-1.riscv64.rpm",
+			prefix + "_1.0.0_riscv64.ipk",
+			prefix + "_1.0.0_riscv64.deb",
 		}, pkg.Name, "package name is not expected")
 		require.Equal(t, "someid", pkg.ID())
 		require.ElementsMatch(t, []string{binPath}, sources(artifact.ExtraOr(*pkg, extraFiles, files.Contents{})))
