@@ -5,12 +5,12 @@ import (
 	"bytes"
 	"errors"
 	"fmt"
+	"maps"
 	"os"
 	"os/exec"
 	"path"
 	"path/filepath"
 	"slices"
-	"sort"
 	"strings"
 	"text/template"
 
@@ -23,7 +23,6 @@ import (
 	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
 	"github.com/goreleaser/goreleaser/v2/pkg/config"
 	"github.com/goreleaser/goreleaser/v2/pkg/context"
-	"golang.org/x/exp/maps"
 )
 
 const nixConfigExtra = "NixConfig"
@@ -175,7 +174,7 @@ func (p Pipe) doRun(ctx *context.Context, nix config.Nix, cl client.ReleaseURLTe
 	}
 
 	log.WithField("nixpkg", path).Info("writing")
-	if err := os.WriteFile(path, []byte(content), 0o644); err != nil { //nolint: gosec
+	if err := os.WriteFile(path, []byte(content), 0o644); err != nil { //nolint:gosec
 		return fmt.Errorf("failed to write nixpkg: %w", err)
 	}
 
@@ -313,11 +312,10 @@ func preparePkg(
 		}
 	}
 
-	if roots := slices.Compact(maps.Values(data.SourceRoots)); len(roots) == 1 {
+	if roots := slices.Compact(slices.Collect(maps.Values(data.SourceRoots))); len(roots) == 1 {
 		data.SourceRoot = roots[0]
 	}
-	data.Platforms = keys(platforms)
-	sort.Strings(data.Platforms)
+	data.Platforms = slices.Sorted(maps.Keys(platforms))
 
 	return doBuildPkg(ctx, data)
 }
@@ -339,14 +337,6 @@ var goosToPlatform = map[string]string{
 	"darwinarm64": "aarch64-darwin",
 }
 
-func keys(m map[string]bool) []string {
-	keys := make([]string, 0, len(m))
-	for k := range m {
-		keys = append(keys, k)
-	}
-	return keys
-}
-
 func doPublish(ctx *context.Context, prefetcher shaPrefetcher, cl client.Client, pkg *artifact.Artifact) error {
 	nix, err := artifact.Extra[config.Nix](*pkg, nixConfigExtra)
 	if err != nil {
