@@ -6,6 +6,7 @@ import (
 	"strings"
 
 	"github.com/charmbracelet/x/exp/ordered"
+	"github.com/goreleaser/goreleaser/v2/internal/experimental"
 	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
@@ -29,7 +30,23 @@ func getFilter() string {
 		target = target + "_" + goamd64
 	}
 	if strings.HasSuffix(target, "_arm") {
-		goarm := ordered.First(os.Getenv("GGOARM"), os.Getenv("GOARM"), "6")
+		goarm := ordered.First(os.Getenv("GGOARM"), os.Getenv("GOARM"), experimental.DefaultGOARM())
+		target = target + "_" + goarm
+	}
+	if strings.HasSuffix(target, "_arm64") {
+		goarm := ordered.First(os.Getenv("GGOARM64"), os.Getenv("GOARM64"), "v8.0")
+		target = target + "_" + goarm
+	}
+	if strings.HasSuffix(target, "_386") {
+		goarm := ordered.First(os.Getenv("GGO386"), os.Getenv("GO386"), "sse2")
+		target = target + "_" + goarm
+	}
+	if strings.HasSuffix(target, "_ppc64") {
+		goarm := ordered.First(os.Getenv("GGOPPC64"), os.Getenv("GOPPC64"), "power8")
+		target = target + "_" + goarm
+	}
+	if strings.HasSuffix(target, "_riscv64") {
+		goarm := ordered.First(os.Getenv("GGORISCV64"), os.Getenv("GORISCV64"), "rva20u64")
 		target = target + "_" + goarm
 	}
 	if strings.HasSuffix(target, "_mips") ||
